icsemantic.catalog.criteria.synonym.ATSynonymCriterion

Package platecom :: Package ontocatalog :: Package criteria :: Module synonym :: Class ATSynonymCriterion |
[hide private]
[frames] | no frames]

# Class ATSynonymCriterion

source code

    Products.ATContentTypes.criteria.simplestring.ATSimpleStringCriterion --+
                                                                            |
                                                                           ATSynonymCriterion

A synonym text criterion

Class Variables | [hide private]
| __implements__ = `ATSimpleStringCriterion.__implements__+(IATTo`...``
| security = `ClassSecurityInfo()`
| schema = `ATSimpleStringCriterionSchema`
| meta_type = `'ATSynonymCriterion'`
| archetype_name = `'Friendly Synonym Criterion'`
| shortDesc = `'Synonym Criterion'`

Class Variable Details | [hide private]

  ### __implements__ Value:
      ATSimpleStringCriterion.__implements__+(IATTopicSearchCriterion,)